==> office-ui-fabric-react-0.34.0.tgz: package/ghdocs/ROADMAP.md <==
# Roadmap

The Office UI Fabric React project is currently in a **pre-v1 state** which means that we're working hard on achieving our v1 - a complete set of powerful and easy to use components built to the Office Design Language. We will be actively working on this set as teams across Office and Office 365 contribute, evolve, and use these components in their own products.

Given the early state of the project, all things are subject to change and some components may be more stable/usable than others. Use at your own risk!

This roadmap serves to show everyone what components we're working on and the states of them as we build them all out so that they are:
- Well documented
- Have clear contracts
- Keyboard accessible
- Screen reader friendly
- RTL friendly
- Support high contrast mode
- Generally bug-free

Components are generally in 4 states: *placeholder*, *started*, *beta*, and *complete*:

| State       | Definition                                                                                                |
|-------------|-----------------------------------------------------------------------------------------------------------|
| Placeholder | The component has little to no functionality.                                                             |
| Started     | Work on the component has begun, but it is not anywhere near production ready.                                                             |
| Beta        | The component is far enough along to be used, but still lacks some functionality or has significant bugs. |
| Complete    | The component is generally bug-free and meets all of the requirements outlined above - production ready!  |


## Components

| Component         |       State |
|-------------------|------------:|
| Breadcrumb        |        Beta |
| Button            |        Beta |
| Callout           |        Beta |
| Checkbox          |        Beta |
| ChoiceGroup       |        Beta |
| ColorPicker       |      Started|
| ContextualMenu    |        Beta |
| DatePicker        |        Beta |
| DetailsList       |        Beta |
| Dialog            |        Beta |
| DocumentCard      |        Beta |
| Dropdown          |        Beta |
| Facepile          |     Started |
| Image             |        Beta |
| Label             |        Beta |
| Layer             |        Beta |
| Link              |        Beta |
| List              |        Beta |
| MessageBar        | Placeholder |
| Nav               |     Started |
| OrgChart          | Placeholder |
| Overlay           |        Beta |
| Panel             |        Beta |
| PeoplePicker      |     Started |
| Persona           |        Beta |
| PersonaCard       | Placeholder |
| Pivot             |     Started |
| ProgressIndicator |        Beta |
| SearchBox         |     Started |
| Spinner           |        Beta |
| Slider            |     Started |
| TextField         |        Beta |
| Toggle            |        Beta |


## Utilities

| Utility              |   State |
|----------------------|--------:|
| Focus trap zones     |    Beta |
| Focus zones          |    Beta |
| Selection management |    Beta |
| Themes               | Started |

==> office-ui-fabric-react-0.47.2.tgz: package/ghdocs/ROADMAP.md <==
# Roadmap

The Office UI Fabric React project is currently in a **pre-v1 state** which means that we're working hard on achieving our v1 - a set of powerful and easy to use components built to the Office Design Language that are used *in production*. We will be actively working on this set as teams across Office and Office 365 contribute, evolve, and use these components in their own products.

Given the early state of the project, all things are subject to change and some components may be more stable/usable than others. Use at your own risk!

This roadmap serves to show everyone what components we're working on and the states of them as we build them all out so that they are:
- Well documented
- Have clear contracts
- Keyboard accessible
- Screen reader friendly
- RTL friendly
- Support high contrast mode
- Generally bug-free

Components are generally in 4 states: *placeholder*, *started*, *beta*, and *complete*:

| State       | Definition                                                                                                |
|-------------|-----------------------------------------------------------------------------------------------------------|
| Placeholder | The component has little to no functionality.                                                             |
| Started     | Work on the component has begun, but it is not anywhere near production ready.                                                             |
| Beta        | The component is far enough along to be used, but still lacks some functionality or has significant bugs. |
| In prod    | The component meets standards that enable it to be used in a production environment - it's production ready!  |


## Components

| Component         |       State |
|-------------------|------------:|
| Breadcrumb        |        Beta |
| Button            |        Beta |
| Callout           |        Beta |
| Checkbox          |        Beta |
| ChoiceGroup       |        Beta |
| ColorPicker       |      Started|
| ContextualMenu    |        Beta |
| DatePicker        |        Beta |
| DetailsList       |        Beta |
| Dialog            |        Beta |
| DocumentCard      |        Beta |
| Dropdown          |        Beta |
| Facepile          |     Started |
| GroupedList       |     Started |
| Image             |        Beta |
| Label             |        Beta |
| Layer             |        Beta |
| Link              |        Beta |
| List              |        Beta |
| MessageBar        | Placeholder |
| Nav               |     Started |
| OrgChart          | Placeholder |
| Overlay           |        Beta |
| Panel             |        Beta |
| PeoplePicker      |     Started |
| Persona           |        Beta |
| PersonaCard       | Placeholder |
| Pivot             |     Started |
| ProgressIndicator |        Beta |
| SearchBox         |     Started |
| Spinner           |        Beta |
| Slider            |        Beta |
| TextField         |        Beta |
| Toggle            |        Beta |


## Utilities

| Utility              |   State |
|----------------------|--------:|
| Focus trap zones     |    Beta |
| Focus zones          |    Beta |
| MarqueeSelection     |    Beta |
| Selection management |    Beta |
| Themes               | Started |
